#include <iostream>

#include <QCoreApplication>
#include <VDream/Common/VCommon.h>
#include <VDream/Log/VLog.h>

using namespace std;

class Param
{
public:
  QString   msg;
  bool      flush;
  bool      linefeed;
  VDuration interval;
  int       count;

public:
  Param()
  {
    msg      = "";
    flush    = false;
    linefeed = false;
    interval = 1000;
    count    = 5;
  }

  bool parse(int argc, char* argv[])
  {
    if (argc < 2) return false;
    msg = argv[1];

    int i = 2;
    while (i < argc)
    {
      QString s = argv[i];
      if (s == "-f")
      {
        flush = true;
      } else
      if (s == "-l")
      {
        linefeed = true;
      } else
      if (s == "-i")
      {
        if (i + 1 >= argc)
        {
          cout << "no value for -i\n";
          return false;
        }
        QString value = argv[i + 1];
        interval = value.toInt();
        i++;
      } else
      if (s == "-c")
      {
        if (i + 1 >= argc)
        {
          cout << "no value for -c\n";
          return false;
        }
        QString value = argv[i + 1];
        count = value.toInt();
        i++;
      } else
      {
        cout << "invalid option " << qPrintable(s) << endl;
        return false;
      }
      i++;
    }
    return true;
  }

  static void usage()
  {
    cout << "src <msg> [-f][-l][-i <interval>][-c <count>]\n";
    cout << "-f            : flush (default false)\n";
    cout << "-l            : linefeed(default false)\n";
    cout << "-i <interval> : interval(default 1000 msec)\n";
    cout << "-c <count>    : count(default 5)\n";
  }
};

int main(int argc, char *argv[])
{
  QCoreApplication a(argc, argv);

  Param param;
  if (!param.parse(argc, argv))
  {
    Param::usage();
    return 0;
  }
  
  /*
  cout << "msg      = " << qPrintable(param.msg) << endl;
  cout << "flush    = " << param.flush<< endl;
  cout << "linefeed = " << param.linefeed << endl;
  cout << "interval = " << param.interval << endl;
  */

  for (int i = 0; i < param.count; i++)
  {
    QString s = QString::number(i);
    s += param.msg;
    if (param.linefeed) s += "\n";
    cout << qPrintable(s);
    if (param.flush) cout.flush();
    LOG_TRACE("src %s", qPrintable(s));
    msleep(param.interval);
  }

  return 0;
}
